@@ -44,13 +44,13 @@ class AioTransport(xmlrpc.Transport):
     """
 
     user_agent = 'python/aioxmlrpc'
-    
 
-    def __init__(self, use_https, use_datetime=False,
-                 use_builtin_types=False):
+    def __init__(self, use_https, *, use_datetime=False,
+                 use_builtin_types=False, loop):
         super().__init__(use_datetime, use_builtin_types)
         self.use_https = use_https
-
+        self._loop = loop
+        self._connector = aiohttp.TCPConnector(loop=self._loop)
 
     @asyncio.coroutine
     def request(self, host, handler, request_body, verbose):
@@ -66,10 +66,10 @@ class AioTransport(xmlrpc.Transport):
         url = self._build_url(host, handler)
         response = None
         try:
-            response = yield from aiohttp.request('POST', url,
-                                                  headers=headers,
-                                                  data=request_body)
-            body = yield from response.read_and_close()
+            response = yield from aiohttp.request(
+                'POST', url, headers=headers, data=request_body,
+                connector=self._connector, loop=self._loop)
+            body = yield from response.text()
             if response.status != 200:
                 raise ProtocolError(url, response.status,
                                     body, response.headers)
@@ -98,6 +98,9 @@ class AioTransport(xmlrpc.Transport):
         scheme = 'https' if self.use_https else 'http'
         return '%s://%s%s' % (scheme, host, handler)
 
+    def close(self):
+    	self._connector.close()
+
 
 class ServerProxy(xmlrpc.ServerProxy):
     """
@@ -105,9 +108,12 @@ class ServerProxy(xmlrpc.ServerProxy):
     """
 
     def __init__(self, uri, transport=None, encoding=None, verbose=False,
-                 allow_none=False, use_datetime=False,use_builtin_types=False):
+                 allow_none=False, use_datetime=False,use_builtin_types=False,
+                 loop=None):
+        self._loop = loop or asyncio.get_event_loop()
         if not transport:
-            transport = AioTransport(uri.startswith('https://'))
+            transport = AioTransport(uri.startswith('https://'),
+                                     loop=self._loop)
         super().__init__(uri, transport, encoding, verbose, allow_none,
                          use_datetime, use_builtin_types)
 
@@ -129,5 +135,8 @@ class ServerProxy(xmlrpc.ServerProxy):
 
         return response
 
+    def close(self):
+    	self.__transport.close()
+
     def __getattr__(self, name):
         return _Method(self.__request, name)
